@@ -35,6 +35,7 @@ csv2oerp is intended to be used to simplify data migration from CSV to OpenERP.
 
 """
 
+import socket
 import os
 import sys
 import xmlrpclib
@@ -187,7 +188,7 @@ class Import_session(object):
             'col_num': 0,
             'line_num': 0,
             'errors': 0,
-            'warnings': 0,
+            'warning': 0,
             'line_skipped': 0,
             'line_done': 0,
             'object_skipped': 0,
@@ -568,7 +569,7 @@ class Import_session(object):
             self._uid = sock_common.login(self.db, self.user, self.pwd)
             self._server = xmlrpclib.ServerProxy(url + 'object', allow_none=True)
         except Exception as error:
-            self._logger.error("connection problem : %s" % error, extra=STATS[self._id])
+            self._logger.critical("connection problem : %s" % error, extra=STATS[self._id])
             sys.exit(EXIT_ERROR)
         
     def connect(self, host=HOST, port=PORT, user=USER, pwd=PWD, dbname=DB):
@@ -634,10 +635,16 @@ class Import_session(object):
         """Return a value by its column position or the callback function
 
         """
+        global STATS
         try:
             column = eval(column)
         except:
             pass
+        try:
+            STATS[self._id]['col_num'] = int(column)
+        except:
+            STATS[self._id]['col_num'] = -1
+            
         # List of indices case
         if isinstance(column, list):
             content = u""
@@ -653,7 +660,7 @@ class Import_session(object):
             content = callback
         return content
     
-    def _search(self, model, data, search=None):
+    def _search(self, model, data, search=None, invariant=3):
         global STATS
         STATS[self._id]['importfile'] = self._filename
         if search is None:
@@ -677,10 +684,20 @@ class Import_session(object):
                 list_search = []
 
         if list_search:
-            res = self.server.execute(self.db, self.uid, self.pwd, model,
+            try:
+                res = self.server.execute(self.db, self.uid, self.pwd, model,
                     'search', list_search, 0, False, False, {'lang': self.lang})
-            self._logger.debug('<%-25s> search result %s' % (model, res),
+                self._logger.debug('<%-25s> search result %s' % (model, res),
                     extra=STATS[self._id])
+            except socket.error as err:
+                if invariant:
+                    STATS[self._id]['warning'] += 1
+                    self._logger.warning("Socket error, restarting search (%s tries left)"
+                            % invariant, extra=STATS[self._id])
+                    return self._search(model, data, search, invariant=invariant-1)
+                else:
+                    self._logger.critical("Socket failed (%s)!" % err,
+                            extra=STATS[self._id])
         
         return res
 
@@ -704,7 +721,7 @@ class Import_session(object):
         """
         for each_model in self.mapping:
             if _get_special_actions(each_model)['unique']\
-                    and  model.split('::')[1] == each_model.split('::')[1]:
+                    and model.split('::')[1] == each_model.split('::')[1]:
                 if 'CREATED::id' in self.mapping[each_model]\
                         and self.mapping[each_model]['CREATED::id']:
                     search = data.keys()
@@ -1100,9 +1117,9 @@ formed, \n\n" % (model, attr)
 
             # If data is empty SKIPPED
             if not data:
+                STATS[self._id]['warning'] += 1
                 self._logger.warning("<%-25s> Null values" % model,
                         extra=STATS[self._id])
-                STATS['objects'][model]['skipped'] += 1
                 res = [False]
             else:
                 try:
@@ -1152,7 +1169,7 @@ formed, \n\n" % (model, attr)
                     (model, search, error), extra=STATS[self._id])
             self._logger.debug("<%-25s> id:%s|state:%s|%s" %\
                 (model, search, state, pformat(data)), extra=STATS[self._id])
-            STATS[self._id]['warnings'] += 1
+            STATS[self._id]['error'] += 1
             STATS['objects'][model]['skipped'] += 1
             STATS['objects'][model]['error'] += 1
         
@@ -1304,8 +1321,6 @@ formed, \n\n" % (model, attr)
                 (column, callback, searchable) = tuple_val
             except:
                 (column, callback, searchable, required) = tuple_val
-            STATS[self._id]['col_num'] = int(bool(column))
-            
             content = self._get_content(model, column, callback)
             
             if callback is not None:
@@ -1313,7 +1328,7 @@ formed, \n\n" % (model, attr)
                     content = self._get_callback(line, current_model, callback,
                             item, content)
                 else:
-                    STATS[self._id]['errors'] += 1
+                    STATS[self._id]['error'] += 1
                     self._logger.error('callback must be a function',
                             extra=STATS[self._id])
                     raise exceptions.SkipLineException()
@@ -1327,11 +1342,12 @@ formed, \n\n" % (model, attr)
                             extra=STATS[self._id])
 
             elif column is None:
-                STATS[self._id]['errors'] += 1
+                STATS[self._id]['error'] += 1
                 self._logger.error('callback is mandatory',
                         extra=STATS[self._id])
                 raise exceptions.SkipLineException()
             #else:
+            #    STATS[self._id]['error'] += 1
             #    self._logger.error('Callback or columns is mandatory.',
             #        extra=STATS[self._id])
             
@@ -1411,7 +1427,7 @@ formed, \n\n" % (model, attr)
 #            """ % (error, STATS[self._id]['line_num'], model, state, search,
 #                        pformat(data)), extra=STATS[self._id])
             #except Exception as error:
-            #    STATS[self._id]['errors'] += 1
+            #    STATS[self._id]['error'] += 1
             #    LOGGER.error("%s %s" % (model, error),extra=STATS[self._id])
             finally:
                 # Keep line incrementation
@@ -1468,7 +1484,7 @@ formed, \n\n" % (model, attr)
             self._logger.info("END import", extra=STATS[self._id])
             
         except KeyboardInterrupt:
-            self._logger.error('CTRL^C caught !', extra=STATS[self._id])
+            self._logger.critical('CTRL^C caught !', extra=STATS[self._id])
             exit = True
 
         finally:
@@ -1478,14 +1494,14 @@ formed, \n\n" % (model, attr)
                         STATS[self._id])
                 sys.stdout.write(' | Line Skipped %(line_skipped)11s' %
                         STATS[self._id])
-                sys.stdout.write(' | Total Errors %(line_skipped)10s' %
+                sys.stdout.write(' | Total Errors %(error)10s' %
                         STATS[self._id])
                 sys.stdout.write('\n')
                 sys.stdout.write('Object Created %(object_created)11s' %
                         STATS[self._id])
                 sys.stdout.write(' | Line Done    %(line_done)11s' %
                         STATS[self._id])
-                sys.stdout.write(' | Total Warnings%(line_skipped)9s' %
+                sys.stdout.write(' | Total Warnings%(warning)9s' %
                         STATS[self._id])
                 sys.stdout.write('\n')
                 sys.stdout.write('Object Written %(object_written)11s' %
@@ -1497,8 +1513,8 @@ formed, \n\n" % (model, attr)
                 'actual_line': 0,
                 'line_num': 0,
                 'col_num': 0,
-                'errors': 0,
-                'warnings': 0,
+                'error': 0,
+                'warning': 0,
                 'line_skipped': 0,
                 'line_done': 0,
                 'object_skipped': 0,
